========
Handlers
========

Module: :mod:`jupyterlab_server.handlers`
=========================================

.. automodule:: jupyterlab_server.handlers

.. currentmodule:: jupyterlab_server.handlers

.. autoclass:: LabHandler
    :members:

.. autofunction:: add_handlers

.. autofunction:: is_url


Module: :mod:`jupyterlab_server.listings_handler`
=================================================

.. automodule:: jupyterlab_server.listings_handler

.. currentmodule:: jupyterlab_server.listings_handler

.. autoclass:: ListingsHandler
    :members:

.. autofunction:: fetch_listings


Module: :mod:`jupyterlab_server.settings_handler`
=================================================

.. automodule:: jupyterlab_server.settings_handler

.. currentmodule:: jupyterlab_server.settings_handler

.. autoclass:: SettingsHandler
    :members:

.. autofunction:: get_settings


Module: :mod:`jupyterlab_server.themes_handler`
=================================================

.. automodule:: jupyterlab_server.themes_handler

.. currentmodule:: jupyterlab_server.themes_handler

.. autoclass:: ThemesHandler
    :members:


Module: :mod:`jupyterlab_server.translations_handler`
=====================================================

.. automodule:: jupyterlab_server.translations_handler

.. currentmodule:: jupyterlab_server.translations_handler

.. autoclass:: TranslationsHandler
    :members:

.. autofunction:: get_current_locale


Module: :mod:`jupyterlab_server.workspaces_handler`
=====================================================

.. automodule:: jupyterlab_server.workspaces_handler

.. currentmodule:: jupyterlab_server.workspaces_handler

.. autoclass:: WorkspacesHandler
    :members:

.. autofunction:: slugify
